# telicent-label-builder


Telicent label builder provides useful helper classes to build and create security labels.

## Dependencies

- Python \>=3.10
- Pydantic

## Installation

```shell
pip install telicent-label-builder
```

## Usage

For documentation on how to use telicent-label-builder, please see the [documentation index](docs/index.md).
